@@ -8,12 +8,8 @@
 
 #include "util/warning.h"
 #include "util/filesys.h"
-#include "defines.h"
 #include "propbase.h"
 
-#define _Str(x) #x
-#define Str(x) _Str(x)
-
 PFile PFile::instance = PFile();
 PFile &config = PFile::instance;
 
@@ -27,7 +23,6 @@ PFile::PFile():
   SingleSided("SingleSided", "Pages are single-sided"),
   PaperName("PaperName", "Default paper"),
   PrintCommand("PrintCommand", "Printing command"),
-  FontPath("FontPath", "Path to look for font files in"),
   StylesheetPath("StylesheetPath", "Path to look for XSLT files in"),
   DefaultStylesheet("DefaultStylesheet", "Default text stylesheet"),
   DocTemplatePath("DocTemplatePath", "Default document template"),
@@ -70,8 +65,6 @@ PFile::PFile():
   declare_var(&PrintCommand);
   PrintCommand.values.push_back("lpr");
 
-  declare_var(&FontPath);
-  FontPath.values.push_back(Str(FONTPATH));
   declare_var(&StylesheetPath);
   StylesheetPath.values.push_back(XMLPATH);
 
