@@ -5,8 +5,8 @@
 ///
 #include "pagent.h"
 #include "fileerrors.h"
+#include "util/xmlwrap.h"
 #include <iostream>
-#include <libxml++/libxml++.h>
 
 namespace Error {
   struct FrameType: public File {
@@ -16,22 +16,26 @@ namespace Error {
 
 class BasicFrame: public Pagent {
 public:
-  BasicFrame(Group *parent, float w, float h, const std::string& name);
-  BasicFrame(Group *parent, const xmlpp::Element& node);
+  BasicFrame(Group *parent, const std::string& name);
+  BasicFrame(const ElementWrap& xml, Group *parent);
   virtual ~BasicFrame();
   
   virtual xmlpp::Element *save(xmlpp::Element& parent_node,
 			       const FileContext &context) const;
   virtual void print(std::ostream &out, bool grayscale = false) const;
-  
-  Boundary get_box() const;
+
+  /**
+   * This implementation of get_obstacle_boundary() returns the bounding box
+   * for the frame, appropriatley grown.  Pagents that works as
+   * non-rectangular boundaries should provide their own implementation.
+   */
   Boundary get_obstacle_boundary() const;
   
   // Errors reported by generate_picture:
   // ASSOCIATION - failed to open associated file
   //  GENERATION - general error (missing program, corrupted file, et cetera)
   //    ZEROSIZE - picture has zero size
-  enum GenPicErrorType { ASSOCIATION, GENERATION, ZEROSIZE }; 
+  enum GenPicErrorType { ASSOCIATION, GENERATION, ZEROSIZE, NOTREADY }; 
   struct GenPicError : public std::logic_error {
     GenPicErrorType type;
     GenPicError(GenPicErrorType t, std::string s)
