@@ -11,8 +11,7 @@ public:
   CachedFrame(Group *parent, const std::string &name);
   CachedFrame(const ElementWrap& xml, Group *parent);
   
-  typedef SigC::Slot1<void, const std::string&> FileCallback;
-  virtual void generate_picture(FileCallback callback) = 0;
+  virtual void generate_picture(std::ostream& psstream) const = 0;
   
 protected:
   bool white_is_transparent; // fake transparency
