@@ -5,6 +5,7 @@
 ///
 #include "util/matrix.h"
 #include "util/boundary.h"
+#include "ps/pdf.h"
 #include <sigc++/object.h>
 #include <sigc++/signal.h>
 #include <libxml++/nodes/element.h>
@@ -25,26 +26,41 @@ namespace Error {
 }
 
 /**
- * A Pagent is a Page Component, something that can be placed on a Page.  Most
- * Pagent's are also BasicFrames (the exact distinction between a Pagent and
- * a BasicFrame is currently rather muddy).
+ * The most general interface to anything on a Page.
+ * A Pagent has a size and a transformation matrix that defines where on the
+ * Page it is.
  */
 class Pagent: public SigC::Object {
 public:
   Pagent(Group *_parent, const std::string& _name);
   virtual ~Pagent();
 
+  /**
+   * Save this Pagent to an xml Element to be included in a Passepartout save
+   * file.
+   * \param parent_node the xml node that the saved element should be in.
+   * \param context a context for handling file names.
+   */
   virtual xmlpp::Element *save(xmlpp::Element& parent_node,
 			       const FileContext &context) const = 0;
+
+  /**
+   * Print this pagent as PostScript.
+   * \param out the stream for the PostScript output.
+   * \param grayscale if true, print grayscale only.
+   */
   virtual void print(std::ostream &out, bool grayscale = false) const = 0; 
-  // should throw PrintError
-
 
+  /**
+   * Print this pagent as PDF.
+   */
+  virtual void print_pdf(PDF::Content::Ptr pdf) const = 0;
+  
+  
   // *** undoable actions ***
   virtual void set_translation(const Vector& v);
   virtual void set_rotation(float angle);
   virtual void set_scaling(float xfactor, float yfactor);
-  virtual void set_size(float w, float h);
   virtual void set_lock(bool _locked);
   // a locked pagent cannot be moved or reshaped with the mouse
   virtual void set_flow_around(bool _flow_around);
@@ -60,10 +76,14 @@ public:
   virtual bool get_lock() const {return locked;}
   virtual Boundary get_box() const = 0;
   virtual const Matrix& get_matrix() const {return matrix;} 
-  bool is_resizable() {return resizable;}
-  virtual float get_width() const {return width;}
-  virtual float get_height() const {return height;}
-
+  
+  /**
+   * Get the inherent size of this object.  The inherent size is the size as
+   * the object sees it, in its own coordinate system (before applying the
+   * matrix).
+   */
+  virtual Vector get_inherent_size() const = 0;
+  
   virtual bool get_flow_around() const {return flow_around;}
   virtual Boundary get_obstacle_boundary() const = 0;
   virtual float get_obstacle_margin() const {return obstacle_margin;}
@@ -85,22 +105,32 @@ public:
   /** There was a change in the source object for this Pagent. */
   SigC::Signal1<void, Pagent*> object_changed_signal;
   
-  SigC::Signal1<void, Pagent*> ready_to_draw_signal; 
-  // indicated to owner that it might want to redraw the pagent
+  /** Anything has changed, anything at all, including position and shape. */
   SigC::Signal1<void, Pagent*> props_changed_signal; 
-  // anything has changed, anything at all, 
-  // including position and shape
-  SigC::Signal1<void, Pagent*> geometry_changed_signal; 
-  // the pagent has changed shape / position
 
+  /** the pagent has changed shape / position */
+  SigC::Signal1<void, Pagent*> geometry_changed_signal; 
+  
+  /**
+   * Resizability contract for Pagents.  That a Pagent inherits Resizable
+   * means that it has an intrinsic size that can be changed.  Other objects
+   * have a fixed intrinsic size (e.g. a raster image) that can't be changed
+   * from inside passepartout.
+   */
+  class Resizable {
+  public:
+    virtual ~Resizable();
+    /** Set the intrinsic size of the pagent. */
+    virtual void set_size(float width, float height) = 0;
+  };
+  
 protected:
   Group *parent;
-  bool resizable, locked, flow_around;
+  bool locked, flow_around;
   Matrix matrix;
   std::string name;
   float obstacle_margin;
-  float width, height;
-
+  
   // connections to parent
   SigC::Connection draw_connection, geometry_connection, props_connection;
   void connect_to_parent();
