@@ -7,11 +7,11 @@
 #include "textstream.h"
 #include <glibmm/dispatcher.h>
 
-class TextFrame : public CachedFrame {
+class TextFrame : public CachedFrame, public Pagent::Resizable {
 public:
   TextFrame(Group *parent, TextStream *stream,
 	     float w, float h);
-  TextFrame(Group *parent, const xmlpp::Element& node);
+  TextFrame(const ElementWrap& xml, Group *parent);
   virtual ~TextFrame();
 
   virtual std::string getTypeName() const;
@@ -19,6 +19,7 @@ public:
   virtual xmlpp::Element *save(xmlpp::Element& parent_node,
 			       const FileContext &context) const;
   virtual void print(std::ostream &out, bool grayscale = false) const;
+  virtual void print_pdf(PDF::Content::Ptr pdf) const;
 
 
   // *** undoable actions ***
@@ -28,12 +29,14 @@ public:
   // in order not to get a segmentation violation
   void set_num_columns(unsigned int columns);
   void set_gutter(const float& gutter);
-  void set_size(float w, float h); // overrides Pagent
+  
+  void set_size(float w, float h);
 
 
   // *** probe state ***
+  Boundary get_box() const;
   TextStream *get_stream() const {return text_stream;}
-  //may return null
+  Vector get_inherent_size() const { return Vector(width, height); }
   unsigned int get_num_columns() const { return num_columns; }
   float get_gutter() const { return gutter_width; }
   
@@ -42,23 +45,28 @@ public:
    * {TextStream}. */
   bool is_truncated() const { return truncated; }
   
+  /** Emitted when the frame is or stops being the last frame of a
+   * truncated stream. */
+  SigC::Signal1<void, bool> truncated_state_changed_signal;
+
   // the frame will not try to read the ps between calls to
   // begin- and end_write_ps
   void begin_write_ps(); 
-  void end_write_ps(bool _ps_exists, bool truncated);
+  void end_write_ps(bool _ps_exists, bool truncated,
+		    const std::string &error="");
 
+  void generate_picture(std::ostream& psstream) const;
+  
 private:
-  void generate_picture(FileCallback callback);
-
   // for making end_write_ps() thread safe:
   Glib::Dispatcher signal_end_write_ps;
   void _end_write_ps();
 
   bool ps_exists, parsed_file_lock, truncated;
-  std::string parsed_file;
+  std::string parsed_file, error;
   TextStream *text_stream;
   unsigned int num_columns;
-  float gutter_width;
+  float gutter_width, width, height;
 };
 
 #endif
