@@ -3,9 +3,7 @@
 ///
 #include "textstream.h"
 #include "getxsltparams.h"
-#include "pptout/widget/usererror.h" // Todo
 #include <algorithm>
-#include <sstream>
 #include <fstream>
 #include <sigc++/slot.h>
 
@@ -16,7 +14,7 @@
 #include "util/os.h"
 #include "util/barrier.h"
 #include "xml2ps/typesetter.hh"
-#include "fonts/fontmanager.hh"
+#include "xml2ps/pdfcanvas.hh"
 
 #include "textframe.h"
 #include "page.h"
@@ -28,17 +26,17 @@ namespace {			// local
   class SortingPredicate {
   public:
     bool operator () (const TextFrame* a, const TextFrame* b) {
-      int a_num, b_num;
       try {
-	a_num = a->get_page_num(); 
-	b_num = b->get_page_num();
+	int a_num = a->get_page_num(); 
+	int b_num = b->get_page_num();
+	if(a_num < b_num)
+	  return true;
+	if(a_num > b_num)
+	  return false;
       } catch (Error::InvalidPageNum e) {
 	// shouldn't happen, but it has happened
+	return true;		// something broken; any order!
       }
-      if(a_num < b_num)
-	return true;
-      if(a_num > b_num)
-	return false;
       
       // Same page, look at boxes.
       const Vector a_vec = a->get_box()->getCorner(Corner::UL);
@@ -50,17 +48,65 @@ namespace {			// local
   };
 
   bool gtk_main_running = false;
+
+  /**
+   * Start an external process running a XLST transform.
+   * \return a Process handle
+   */
+  Process runXsltProc(const std::string& transform,
+		      const std::string& association,
+		      const TextStream::ParamIter& begin,
+		      const TextStream::ParamIter& end) {
+    debug << "Applying XSL Transform" << std::endl;
+    // Assume xsltproc is in the path
+    std::vector<std::string> command;
+    command.push_back("xsltproc");
+    command.push_back("--nonet");
+    command.push_back("--catalogs");
+    
+    for(TextStream::ParamIter i = begin; i != end; ++i)
+      if(!i->second.empty()) {
+	command.push_back("--stringparam");
+	command.push_back(i->first);
+	command.push_back(i->second);
+      }
+    command.push_back(transform);
+    command.push_back(association);
+    
+    Process xformproc = ProcessManager::instance().run(command);
+    if(debug) {
+      debug << "Started " << xformproc->get_pid() << ':';
+      for(std::vector<std::string>::const_iterator i = command.begin();
+	  i != command.end(); ++i)
+	debug << ' ' << *i;
+      debug << "" << std::endl;
+    }
+    return xformproc;
+  }
 }
 
 
 class TextStream::WorkerThread : public SigC::Object {
 public:
-  WorkerThread(TextStream& stream, const Frames& frames);
-  ~WorkerThread();
+  static Glib::RefPtr<WorkerThread> create(TextStream& stream,
+                                           const Frames& frames) {
+    Glib::RefPtr<WorkerThread> tmp(new WorkerThread(stream, frames));
+    tmp->reference();
+    tmp->self = tmp;
+    return tmp;
+  }
   
+  /// replaces SigC::Object::reference
+  void reference() const { ++count_; }
+  /// replaces SigC::Object::unreference
+  void unreference() const { if(--count_ == 0) delete this; }
+
   bool is_done();
   
 private:
+  WorkerThread(TextStream& stream, const Frames& frames);
+  ~WorkerThread();
+
   void run();
   void run_xml2ps(istream& source);
 
@@ -68,6 +114,16 @@ private:
   void on_error();
   
   void process_stopped(pid_t  pid, bool exited_normally, int exit_code);
+  
+  /// reference count
+  mutable unsigned int count_;
+
+  /// Keeps a reference to itself, so that the object is not deleted
+  /// until self is set to null explicitly, which should happen in
+  /// on_done() or on_error(). The idea is that the object should be
+  /// kept from being deleted until we are sure the Dispatcher pipe is
+  /// empty.
+  Glib::RefPtr<WorkerThread> self;
 
   Barrier started, done;
   TextStream& stream;
@@ -81,7 +137,7 @@ private:
 };
 
 TextStream::WorkerThread::WorkerThread(TextStream& s, const Frames& frames)
-  : stream(s), sorted_frames(frames), truncated(false),
+  : count_(0), stream(s), sorted_frames(frames), truncated(false),
     proc_stop_connection(ProcessManager::instance().process_stopped.connect
 			 (SigC::slot(*this, 
 				     &WorkerThread::process_stopped)))
@@ -101,7 +157,6 @@ TextStream::WorkerThread::WorkerThread(TextStream& s, const Frames& frames)
 }
 
 TextStream::WorkerThread::~WorkerThread() {
-  /// \todo Kill the process, stop the work ...
   proc_stop_connection.disconnect();
   if(xformproc)
     kill(xformproc->get_pid(), SIGTERM);
@@ -134,23 +189,14 @@ TextStream::TextStream(const std::string& _name,
   Glib::signal_idle().connect(SigC::slot(*this, &TextStream::on_idle));
 }
 
-TextStream::TextStream(const xmlpp::Element& node, const FileContext &context)
-  : failed(false),
-    association_watcher(""), transform_watcher(""),
+TextStream::TextStream(const ElementWrap& xml)
+  : name(xml.get_attribute<string>("name")),
+    association(xml.get_filename("file")),
+    transform(xml.get_filename("transform")),
+    failed(false),
+    association_watcher(association), transform_watcher(transform),
     typesetter_thread(0)
 {
-  xmlpp::Attribute *prop;
-  if((prop = node.get_attribute("name")))
-    name = prop->get_value();
-  if((prop = node.get_attribute("file"))) {
-    association = context.from(prop->get_value());
-    association_watcher.set_file(association);
-  }
-  if((prop = node.get_attribute("transform"))) {
-    transform = context.from(prop->get_value());
-    transform_watcher.set_file(transform);
-  }
-
   // read param defs
   typedef std::vector<std::string> Vec;
   Vec params = getXsltParams(transform);
@@ -158,7 +204,7 @@ TextStream::TextStream(const xmlpp::Element& node, const FileContext &context)
     parameters[*i] = "";
 
   //read param values
-  xmlpp::Element::NodeList children = node.get_children();
+  xmlpp::Element::NodeList children = xml.element().get_children();
   for(xmlpp::Element::NodeList::iterator i = children.begin();
       i != children.end();
       ++i) 
@@ -230,6 +276,8 @@ void TextStream::remove_frame(TextFrame *text_frame) {
 			    text_frame);
   if(i != frames.end()) 
     frames.erase(i);
+
+  run_typesetter();
 }
 
 void TextStream::generate_ps_request(TextFrame *frame) {
@@ -239,7 +287,7 @@ void TextStream::generate_ps_request(TextFrame *frame) {
   if(failed) { // the last attempt failed
     failed = false; // so we can try again
     throw BasicFrame::GenPicError(BasicFrame::GENERATION, 
-				     typesetter_error);
+				  typesetter_error);
   }
 
   run_typesetter();
@@ -262,17 +310,17 @@ void TextStream::run_typesetter() {
     return;
   }
   
-  /// \todo  Tell the old thread to stop and start a new one, this method is
-  /// (should be) called when there is a _new_ change in the soruce or frame
+  /// \todo {Tell the old thread to stop and start a new one, this method is
+  /// (should be) called when there is a _new_ change in the source or frame
   /// formats only.  This way we lag behind.
   /// ... or possibly just accept a little lag, but in that case, make sure a
-  /// new typesetter_thread is started after the last one that was ignored.
+  /// new typesetter_thread is started after the last one that was ignored.}
   
   // start typesetter in separate thread
   if(!typesetter_thread || typesetter_thread->is_done())
-    typesetter_thread = new WorkerThread(*this, frames);
+    typesetter_thread = WorkerThread::create(*this, frames);
   else
-    debug << "TypeSetter allready working, not starting new." << std::endl;
+    debug << "Typesetter already working, not starting new." << std::endl;
 }
 
 void TextStream::WorkerThread::run() {
@@ -289,22 +337,9 @@ void TextStream::WorkerThread::run() {
       run_xml2ps(source);
       
     } else {
-      debug << "Apply stylesheet" << std::endl;
-      std::ostringstream cmd;
-      // Assume xsltproc is in the path
-      cmd << "xsltproc --nonet --catalogs";
-      for(ParamIter i = stream.parameters.begin(); 
-	  i != stream.parameters.end(); ++i)
-	if(!i->second.empty())
-	  cmd << " --param " << i->first << " '\"" << i->second << "\"'";
-      cmd << ' ' << stream.transform << ' ' << stream.association;
-      
-      xformproc = ProcessManager::instance().run(cmd.str());
-      pid_t pid = xformproc->get_pid();
-      verbose << pid<< ": " << cmd.str() << std::endl;
-      if(pid == -1)
-	throw BasicFrame::GenPicError(BasicFrame::GENERATION, 
-				      "Failed to run xsltproc");
+      xformproc = runXsltProc(stream.transform, stream.association,
+			      stream.parameters.begin(),
+			      stream.parameters.end());
       
       run_xml2ps(xformproc->get_cout());
     }
@@ -314,7 +349,6 @@ void TextStream::WorkerThread::run() {
     debug << " signalled done from " << Glib::Thread::self() << std::endl;
   } catch (...) {
     started.open(); // make sure the barrier actually opens even on errors.
-    debug << "typesetter error: " << stream.typesetter_error << std::endl;
     // have to let main thread resume
     // even if there is an error
     if(stream.typesetter_error.empty()) {
@@ -325,6 +359,7 @@ void TextStream::WorkerThread::run() {
 	stream.typesetter_error = "unknown error";
       }
     }
+    debug << "typesetter error: " << stream.typesetter_error << std::endl;
     done.open();
     signal_error();
   }
@@ -336,9 +371,9 @@ void TextStream::WorkerThread::run_xml2ps(std::istream& source) {
       i != sorted_frames.end(); 
       i++) {
     (*i)->begin_write_ps();
+    const Vector framesize = (*i)->get_inherent_size();
     pages.push_back(xml2ps::PageBoundary((*i)->get_page_num(),
-					 (*i)->get_width(),
-					 (*i)->get_height(),
+					 framesize.x, framesize.y,
 					 (*i)->get_num_columns(),
 					 (*i)->get_gutter()));
     
@@ -370,7 +405,6 @@ void TextStream::WorkerThread::run_xml2ps(std::istream& source) {
   try {
     parser.parse_stream(source);
   } catch(const xml2ps::OutOfPages&) {
-    std::cerr << "Out of pages in " << stream.name << std::endl;
     truncated = true;
   }
 }
@@ -379,6 +413,11 @@ void TextStream::WorkerThread::run_xml2ps(std::istream& source) {
  * This method should run in the main GUI thread when the worker is done.
  */
 void TextStream::WorkerThread::on_done() {
+  // make sure the the WorkerThread won't keep any references to
+  // itself after this method has returned.
+  Glib::RefPtr<WorkerThread> tmp = self;
+  self.clear();
+
   debug << "Acting on done signal in " << Glib::Thread::self()
 	<< std::endl;
   stream.used_fonts = new_canvas->getUsedFonts();
@@ -401,9 +440,14 @@ void TextStream::WorkerThread::on_done() {
  * This method should run in the main GUI thread if the worker fails.
  */
 void TextStream::WorkerThread::on_error() {
+  // make sure the the WorkerThread won't keep any references to
+  // itself after this method has returned.
+  Glib::RefPtr<WorkerThread> tmp = self;
+  self.clear();
+
   for(Frames::const_iterator i = sorted_frames.begin(); 
       i != sorted_frames.end();  ++i)
-    (*i)->end_write_ps(false, false);
+    (*i)->end_write_ps(false, false, stream.typesetter_error);
 
   stream.failed = true; // report the last attempt to be a failure  
 
@@ -424,19 +468,20 @@ void TextStream::WorkerThread::process_stopped(pid_t pid,
     return; /// \todo do something clever
   }
 
-  debug << pid << ", exit code: " << exit_code << std::endl;
-
-  if(exit_code == 127) { // the shell could not find xsltproc
-    warning << "xsltproc is not in $PATH" << std::endl;
-    return; /// \todo deal with this
+  if(exit_code != 0) {
+    /// \todo check that the return code 127 is not unique to Bash.
+    if(exit_code == 127) // the shell could not find xsltproc
+      warning << "xsltproc is not in $PATH" << std::endl;
+    else
+      warning << "xsltproc process with pid " << pid
+	      << " failed with exit code " << exit_code << std::endl;
+    return;
   }
-  /// \todo check that the return code 127 is not unique to Bash.
   
   debug << "Stylesheet done" << std::endl;
 }
 
 void TextStream::set_association(const std::string &s) {
-  /// \todo run ready_to_draw_signal for all frames. Maybe.
   association = s;
   // perhaps it has been applied, but not for this file
   try { on_file_modified(); } 
@@ -475,7 +520,7 @@ void TextStream::set_parameter(const std::string& name,
 
 void TextStream::outputPageRaw(std::ostream& out, const TextFrame* frame) {
   if(canvas) {
-    canvas->flush();
+    canvas->closePage();
     canvas->appendPage(pageno_map[frame], out);
   } else
     throw std::runtime_error("Missing canvas while running outputPageRaw");
@@ -483,12 +528,89 @@ void TextStream::outputPageRaw(std::ostream& out, const TextFrame* frame) {
   
 void TextStream::outputPageEps(std::ostream& out, const TextFrame* frame) {
   if(canvas) {
-    canvas->flush();
+    canvas->closePage();
     canvas->pageEps(pageno_map[frame], out);
   } else
     throw std::runtime_error("Missing canvas while running outputPageEps");
 }
 
+
+void TextStream::print_pdf(PDF::Document::Ptr pdfdoc) {
+  // don't try to print streams with no pages
+  if(frames.empty())
+    return;
+
+  debug << "TextStream:p-pdf: a\n";
+  Process xformproc;
+  // run xsltproc, but only if there is a stylesheet
+  if(!transform.empty()) {
+    xformproc = runXsltProc(transform, association,
+			    parameters.begin(), parameters.end());
+  }
+
+  debug << "TextStream:p-pdf: c\n";
+  
+  xml2ps::Canvas::PageVec pages;
+  Frames sorted_frames(frames);
+  sorted_frames.sort(SortingPredicate());
+  for(Frames::const_iterator i = sorted_frames.begin(); 
+      i != sorted_frames.end(); 
+      i++) {
+    const Vector framesize = (*i)->get_inherent_size();
+    pages.push_back(xml2ps::PageBoundary((*i)->get_page_num(),
+					 framesize.x, framesize.y,
+					 (*i)->get_num_columns(),
+					 (*i)->get_gutter()));
+    
+    // A boundary for the actual text frame, to make sure it doesn't try to
+    // flow around itself.
+    const Boundary boundary = (*i)->get_obstacle_boundary();
+    
+    // Transform from page coords to local textframe coords.
+    const Matrix xform((*i)->get_matrix().inv());
+    
+    // List of boundaries the text should flow around
+    const BoundaryVect obstacle_list = Page::containing(**i).obstacle_list();
+    for(BoundaryVect::const_iterator j = obstacle_list.begin();
+	j != obstacle_list.end();
+	j++) {
+      if(boundary != *j) {
+	pages.back().addObstacle(*j * xform);
+      }
+    }
+  }
+  
+  debug << "TextStream:p-pdf: running internal xml2ps ..." << std::endl;
+  
+  pdfcanvas.reset(new xml2ps::PDFCanvas(pdfdoc, xml2ps::PDFCanvas::XObjs,
+					pages,
+					false /* no extra pages */));
+  //canvas.setSubstituteFontAliases(true);
+  debug << "TextStream:p-pdf: parser" << std::endl;
+  xml2ps::PsConverter parser(*pdfcanvas);
+  try {
+    debug << "TextStream:p-pdf: parsing" << std::endl;
+    if(xformproc) {
+      parser.parse_stream(xformproc->get_cout());
+    } else {
+      std::ifstream file(association.c_str());
+      parser.parse_stream(file);
+    }
+    pdfcanvas->closePage();
+  } catch(const xml2ps::OutOfPages&) {
+    warning << "content truncated\n";
+  }
+  debug << "TextStream:p-pdf: done" << std::endl;
+}
+
+PDF::Object::Ptr TextStream::getPagePDF(const TextFrame* frame) {
+  if(pdfcanvas.get()) {
+    return pdfcanvas->getPageObject(pageno_map[frame]);
+  } else
+    throw std::runtime_error("Missing canvas while running getPagePDF");
+}
+
+
 // a hack to make sure the gtkmm main loop is running before we
 // start any threads
 bool TextStream::on_idle() {
