@@ -4,13 +4,15 @@
 // Copyright (C) 2002 - 2004, Fredrik Arnerup & Rasmus Kaj, See COPYING
 ///
 #include "util/filewatcher.h"
+#include "util/xmlwrap.h"
 #include "xml2ps/pscanvas.hh"
+#include "ps/pdf.h"
 #include "filecontext.h"
 #include <list>
-#include <libxml++/nodes/element.h>
 #include <sigc++/object.h>
 
 class TextFrame;
+namespace xml2ps { class PDFCanvas; }
 
 /**
  * A source of text associated with a set of TextFrame s.
@@ -43,7 +45,7 @@ public:
    * \param context information about the file we are loading from, for
    * relative URIs etc.
    */
-  TextStream(const xmlpp::Element& node, const FileContext &context);
+  TextStream(const ElementWrap& xml);
   ~TextStream();
 
   /**
@@ -86,6 +88,9 @@ public:
   /** Get the eps data for a specific frame from the canvas */
   void outputPageEps(std::ostream& out, const TextFrame* frame);
   
+  void print_pdf(PDF::Document::Ptr pdfdoc);
+  PDF::Object::Ptr getPagePDF(const TextFrame* frame);
+  
 protected:
   typedef std::list<TextFrame*> Frames;
   std::string name, association, transform;
@@ -109,6 +114,8 @@ private:
   class WorkerThread;
   Glib::RefPtr<WorkerThread> typesetter_thread;
   
+  std::auto_ptr<xml2ps::PDFCanvas> pdfcanvas;
+  
   // Undefined ctors, avoid defaults
   TextStream(const TextStream&);
   TextStream();
