@@ -1,23 +1,25 @@
 #ifndef DOCVIEW_H		// -*- c++ -*-
 #define DOCVIEW_H
 ///
-// Copyright (C) 2002, 2003, Fredrik Arnerup & Rasmus Kaj, See COPYING
+// Copyright (C) 2002 - 2004, Fredrik Arnerup & Rasmus Kaj, See COPYING
 ///
 #include "view.h"
-#include "group.h"
+#include "viewent.h"
+#include "document/group.h"
+#include "docmeta.h"
 #include <gdkmm.h>
-#include <gtkmm/drawingarea.h>
+#include <libgnomecanvasmm.h>
+#include <memory> // auto_ptr
 
-class Pagent;
-class Template_Page_Dialog;
+class TemplatePageDialog;
 class Page;
-class Document;
+class TextStream;
 
 namespace snap {
   enum Mode {GRID, GUIDE, NONE};
 }
 
-class Document_View: public Gtk::DrawingArea, public View {
+class DocumentView: public Gnome::Canvas::Canvas, public View {
 public:
   SigC::Signal0<void> current_page_num_changed_signal;
   SigC::Signal0<void> document_changed_signal;
@@ -26,47 +28,44 @@ public:
 
   Gdk::Color white, black, gray, red;
 
-  Document_View(Document*);
-  ~Document_View();
-  void set_document(Document *d);
-  Document *get_document() const {return document;}
+  DocumentView(DocMeta, float zoom_factor = 1.0);
+  ~DocumentView();
+
+  void set_document(DocMeta d);
+  DocRef get_document() const { return document.get_document(); }
+  DocMeta get_document_meta() const { return document; }
   void set_current_page_num(int);
-  int get_current_page_num() const {return current_page_num;}
-  void draw(bool reshaping = false);
+  int get_current_page_num() const { return current_page_num; }
   Page* get_page();
-  float get_zoom_factor() const {return zoom_factor;}
+  float get_zoom_factor() const { return zoom_factor; }
   void set_zoom_factor(float);
 
   void insert_page_before();
   void insert_page_after();
   void delete_page();
 
-  void undo();
-  void redo();
-
   void copy();
   void cut();
   void paste();
 
   void delete_selected();
-  void rearrange_selected(Rearrange_Target target);
+  void rearrange_selected(RearrangeTarget target);
   void group_selected();
   void ungroup_selected();
-  void new_text_frame();
-  void new_image_frame(std::string, float res = -1, bool catch_errors = true);
+  void new_text_frame(TextStream *stream);
+  void new_image_frame(std::string, float res = -1);
   void select_all_frames();
   void unselect_all_frames();
-  Glib::RefPtr<Gdk::Drawable> get_win()
-  {return win;}
-  Glib::RefPtr<Gdk::GC> get_gc()
-  {return gc;}
+
+  Gnome::Canvas::Group& get_pagent_group() { return pagent_group; }
+  Gnome::Canvas::Group& get_guide_group() { return guide_group; }
+
   const Gdk::Color& get_color(Color::Id color) const;
 
-  void set_snap(snap::Mode mode) {snap_mode = mode;}
-  snap::Mode get_snap() const {return snap_mode;}
+  void set_snap(snap::Mode mode) { snap_mode = mode; }
+  snap::Mode get_snap() const { return snap_mode; }
 		
-  IVector get_origin() const;
-  double get_scrres() const {return resolution * zoom_factor;}
+  double get_scrres() const { return resolution * zoom_factor; }
   float pt2scr(float pt) const;
   float scr2pt(float scr) const;
   // Important! the scalar versions of pt2scr and scr2pt only perform
@@ -74,53 +73,60 @@ public:
   // right- and left-handed coordinate systems
   Gdk::Point pt2scr(const Vector& pt) const;
   Vector scr2pt(const Gdk::Point& scr) const;
-  int page_height() const;
-  int page_width() const;
-
-  Glib::RefPtr<const Gdk::Pixmap> get_wait_pixmap() const 
-  {return wait_pixmap;}
-  Glib::RefPtr<const Gdk::Pixmap> get_missing_pixmap() const 
-  {return missing_pixmap;}
-  Glib::RefPtr<const Gdk::Pixmap> get_broken_pixmap() const 
-  {return broken_pixmap;}
 
   bool on_key_press_event(GdkEventKey*); // called from Window
 
 private:
   // Undefined ctors, avoid defaults
-  Document_View(const Document_View&);
-  Document_View();
-  void operator = (const Document_View&);
+  DocumentView(const DocumentView&);
+  DocumentView();
+  void operator = (const DocumentView&);
 
   Glib::RefPtr<Gdk::Window> win;
-  Glib::RefPtr<Gdk::GC> gc;
+  Viewent::Ref pageview;
+  Gnome::Canvas::Group no_pages_group, pagent_group, guide_group, handle_group;
+  std::auto_ptr<Gnome::Canvas::Rect> no_pages_frame;
+  std::auto_ptr<Gnome::Canvas::Text> no_pages_text;
+  Gnome::Canvas::Rect *handles[8]; /// managed by the canvas
+
+  /// a connection to the selected pagents geometry_changed_signal
+  SigC::Connection selected_geometry_connection;
+  /// a connection to the selected pagents props_changed_signal
+  SigC::Connection selected_props_connection;
+  /// keep track of which pagent the connection is to
+  Pagent *last_selected;
 
   snap::Mode snap_mode;
   int margin_size;
   float resolution; //ppi
   float zoom_factor;
-  float old_width, old_height;
+  Vector old_size;
   Matrix old_matrix;
   IVector offset;
   int reshape_box, current_page_num;
   bool moving, reshaping;
-  Document *document;
+  DocMeta document;
   Page *old_page; //last page visited
-  Template_Page_Dialog *template_page_dialog;
-  Glib::RefPtr<Gdk::Pixmap> wait_pixmap, missing_pixmap, broken_pixmap;
+  std::auto_ptr<TemplatePageDialog> template_page_dialog;
 
   void on_clipboard_get(Gtk::SelectionData& selection_data, guint info);
   void on_clipboard_clear();
   void on_clipboard_received(const Gtk::SelectionData& selection_data);
 
+  /// If there is a reshape box at pixel coordinates (x, y) return the
+  /// index of the box, otherwise return -1.
+  int hover_reshape(int x, int y);
+  /// Set the scroll region of the canvas to fit the size of the document
+  void reset_scroll_region();
+
   void on_realize();
-  bool on_expose_event(GdkEventExpose*);
   bool on_button_press_event(GdkEventButton*);
   bool on_button_release_event(GdkEventButton*);
   bool on_motion_notify_event(GdkEventMotion*);
   void on_drag_data_received(const Glib::RefPtr<Gdk::DragContext>& context, 
 			     int x, int y, GtkSelectionData* selection_data, 
 			     guint info, guint time);
+  void update_handles();
 
   void refresh_streams();
   void begin_move(int x, int y);
@@ -129,21 +135,17 @@ private:
   void end_reshape(bool revert);
   void move_reshape_box(int x, int y);
 
-  void act_on_document_change(Document *document_);
+  void act_on_document_change(DocRef document_);
+  void act_on_selection_change(DocRef document_);
+  void update_document_size(DocRef document_);
   Gdk::Cursor get_cursor(int x, int y);
   void update_cursor(int x, int y);
   bool in_move_area(int x, int y);
   Pagent* in_select_area(int x, int y);
-  void adjust_size();
-  void act_on_size_change(Document *document_);
-  void maybe_page_ready_to_draw(Pagent *pagent);
+
+  SigC::Connection connect_zoom_change(SigC::Slot1<void, float> slot) {
+    return zoom_change_signal.connect(slot);
+  }
 };
 
 #endif
-
-
-
-
-
-
-
