@@ -5,6 +5,7 @@
 ///
 #include "viewent.h"
 #include "document/group.h"
+#include "document/document.h"	// all this just for the selection ...
 #include <vector>
 
 class GroupViewent : public Viewent {
@@ -17,6 +18,7 @@ public:
   
 protected:
   const Pagent* get_frame() const { return frame; }
+  void update_selection(const Document::Selection& selected);
   
 private:
   /** Callback for group_chagned_signal */
@@ -25,8 +27,6 @@ private:
   View* subview;
   FrameRef frame;
   SigC::Connection groupcon;
-
-protected:  		     	/// \todo maybe private?
   ChildVec childvec;
 };
 
