@@ -15,10 +15,17 @@ Pagent* ImageMeta::load(const ElementWrap& xml, Group* parent)
 }
 
 Viewent::Ref ImageMeta::create_viewent(View& view, Pagent& node) {
-  Viewent::Ref result(new PostscriptViewent
-		      (view, &dynamic_cast<ImageFrame&>(node)));
+  PostscriptViewent* rawresult
+    = new PostscriptViewent(view, &dynamic_cast<ImageFrame&>(node));
+  Viewent::Ref result(rawresult);
   result->set_manage(); // turn refcounting on
   result->reference();
+
+  // Images should be re-rastered when geometry changes, but not text frames,
+  // so connect this signal here rather than in the result.
+  node.geometry_changed_signal.connect
+    (SigC::hide<Pagent*>(slot(*rawresult, &PostscriptViewent::regenerate)));
+
   return result;
 }
 
