@@ -4,7 +4,6 @@
 
 #include <gtkmm/main.h>
 
-#include "fonts/fontinfo.hh"
 #include "util/warning.h"
 #include "util/tempfile.h"
 #include "util/cmdline.h"
@@ -17,7 +16,7 @@
 
 int main(int argc, char *argv[]) {
   try {
-    ErrorDialog::init_handler();
+    init_exception_handler();
     int win_count = 0;
 
     // set prefix for temp files
@@ -89,15 +88,6 @@ int main(int argc, char *argv[]) {
       win_count++;
     }
 
-    // initialize font paths
-    font::FontInfo::FontPaths font_paths;
-    for(Config::Strings::const_iterator i = config.FontPath.values.begin();
-	i != config.FontPath.values.end();
-	i++) {
-      font_paths.push_back(*i);
-    }
-    font::FontInfo::init(&font_paths);
-  
     // if no windows were opened, don't run the kit 
     if(win_count) {
       gdk_rgb_init();		// Needed before rendering pixbuf to screen.
