@@ -5,6 +5,7 @@
 ///
 #include "groupviewent.h"
 #include "document/page.h"
+#include <memory> // auto_ptr
 
 /**
  * {Viewent} for a {Page}.  Responsible for drawing guides etc, {GroupViewent}
@@ -16,14 +17,16 @@ public:
   PageViewent(View& view, const FrameRef page);
   ~PageViewent();
   
-  bool draw_content();
-  void clear();
-  
 protected:
   const Pagent* get_frame() const { return page; }
   
 private:
+  void on_size_changed(DocRef doc);
+  void on_selection_changed(DocRef doc);
+
   FrameRef page;
+  std::auto_ptr<Gnome::Canvas::Rect> paper;
+  Gnome::Canvas::Group guide_group;
 };
 
 #endif
