@@ -1,7 +1,7 @@
 #ifndef PRINTDIALOG_H		// -*- c++ -*-
 #define PRINTDIALOG_H
 ///
-// Copyright (C) 2002, 2003, Fredrik Arnerup & Rasmus Kaj, See COPYING
+// Copyright (C) 2002 - 2004, Fredrik Arnerup & Rasmus Kaj, See COPYING
 ///
 
 #include "widget/dialogwrap.h"
@@ -10,6 +10,7 @@
 #include <gtkmm/radiobutton.h>
 #include <gtkmm/checkbutton.h>
 #include <gtkmm/entry.h>
+#include <gtkmm/optionmenu.h>
 
 class DocumentView;
 
@@ -21,16 +22,20 @@ public:
 private:
   Gtk::RadioButton using_button, file_button, 
     all_button, current_button, from_button;
-  Gtk::CheckButton eps_button, fonts_button, gray_button;
+  Gtk::CheckButton fonts_button, gray_button;
   Gtk::Entry using_entry;
+  Gtk::OptionMenu format_menu;
+  Gtk::Widget *pages_box;
   Spinner from_spinner, to_spinner;
   DocumentView &document_view; // document_view keeps record of the document
   FileEntry file_entry;
   Filesel *filesel;
 
-  std::string saved_file_text, saved_using_text;
+  std::string saved_file_text, saved_using_text, saved_format;
   bool saved_file_not_using, saved_eps, saved_gray, saved_fonts;
 
+  Glib::ustring get_format() const;
+  void set_format(const Glib::ustring &format);
   void on_response(int response_id);
   void save_state(); // in case cancel is pressed we will restore inital state
   void restore_state();
