@@ -1,7 +1,7 @@
 #ifndef PROPERTIESDIALOG_H	// -*- c++ -*-
 #define PROPERTIESDIALOG_H
 ///
-// Copyright (C) 2002, 2003, Fredrik Arnerup & Rasmus Kaj, See COPYING
+// Copyright (C) 2002 - 2004, Fredrik Arnerup & Rasmus Kaj, See COPYING
 ///
 #include "document/document.h"
 #include "widget/dialogwrap.h"
@@ -17,12 +17,11 @@ class PropBase;
  * dialog will show properties for that object.
  * This is a Singleton.
  */
-class PropertiesDialog : public DialogWrap {
+class PropertiesDialog : public UtilityWindow {
 public:
   static PropertiesDialog &instance();
   
   void show_raise();		// Make sure this dialog is visible
-  void apply();			// Apply changes done in this dialog
   
   DocRef get_document() const { return document; }
   void set_document(DocRef document_);
@@ -40,9 +39,10 @@ private:
   // no destructor
   ~PropertiesDialog();
 
+  void PropertiesDialog::show_page_contents(GtkNotebookPage*, guint index);
+
   Gtk::Notebook book;
   std::vector<PropBase*> pages;
-  Gtk::Button apply_button, close_button;
 };
 
 #endif
