@@ -1,14 +1,14 @@
 ///
-// Copyright (C) 2002, 2003, Fredrik Arnerup & Rasmus Kaj, See COPYING
+// Copyright (C) 2002 - 2004, Fredrik Arnerup & Rasmus Kaj, See COPYING
 ///
-#include <glibmm.h>
 #include "webbrowser.h"
-#include "errordialog.h"
-#include "globals.h"  // version
+#include "widget/usererror.h"
+#include "defines.h" // VERSION
 #include "util/filesys.h"
+#include <glibmm/spawn.h>
 
 namespace {
-  std::string browser = "gnome-moz-remote";
+  const std::string browser = "gnome-moz-remote";
 }
 
 const std::string homepage = "http://www.stacken.kth.se/project/pptout/";
@@ -16,8 +16,9 @@ const std::string homepage = "http://www.stacken.kth.se/project/pptout/";
 void open_url(const std::string &url) {
   try {
     Glib::spawn_command_line_async(browser + " \"" + url + "\"");
-  } catch(Glib::SpawnError e) {
-    Error_Dialog::view("Couldn't run " + browser + "\n\n" + e.what());
+    
+  } catch(const Glib::SpawnError& e) {
+    throw UserError("Failed to run web browser \"" + browser + '"', e.what());
   }
 }
 
@@ -29,7 +30,7 @@ void open_docs() {
     url = "file://" + url;
   else
     url = "http://www.stacken.kth.se/project/pptout/doc/" 
-      + version 
+      + std::string(VERSION)
       + "/users_guide.html";
   open_url(url);
 }
