@@ -51,7 +51,6 @@ Spinner::Spinner(const float _value, bool allow_float,
   if(!allow_float)
     spinbutton->set_snap_to_ticks(true);
   pack_start(*spinbutton);
-  spinbutton->signal_changed().connect(signal_changed.slot());
   
   if(units) { // only add menu if we have units for it
     menu = manage(new Gtk::Menu());
@@ -117,6 +116,10 @@ float Spinner::get() const {
   return value->get_real_value();
 }
 
+Glib::SignalProxy0<void> Spinner::signal_value_changed() {
+  return value->signal_value_changed();
+}
+
 bool Spinner::on_mnemonic_activate(bool group_cycling) {
   // Not much documented in gtkmm, but it seems this metod gets called when
   // this widget is activated (by a mnemonic e.g. from a label) so I can put
