@@ -1,33 +1,36 @@
 // -*- c++ -*-
 ///
-// Copyright (C) 2002, 2003, Fredrik Arnerup & Rasmus Kaj, See COPYING
+// Copyright (C) 2002 - 2004, Fredrik Arnerup & Rasmus Kaj, See COPYING
 ///
 #ifndef W_SPINNER_H		
 #define W_SPINNER_H
 #include <gtkmm/box.h>
 #include <gtkmm/spinbutton.h>
-#include <pptout/lengthunits.h>
 #include <gtkmm/optionmenu.h>
-// A spinbutton with an optional unit menu.
+#include "pptout/lengthunits.h"
 
 class UnitAdjustment;
 
+/** A spinbutton with an optional unit menu. */
 class Spinner : public Gtk::HBox {
 public:
   Spinner(const float _value = 0, bool allow_float = true, 
-	  const FUUnits *_units = 0);
+	  const FUUnits *_units = 0, 
+	  const Glib::ustring &default_unit = Glib::ustring(),
+	  const float _lo_value = -8000, 
+	  const float _hi_value = 8000);
   ~Spinner();
 
-  void limits(const float& low, const float& high);
+  void limits(float low, float high);
 
   void set_unit(const Glib::ustring &unit);
-  void set(const float& _value);
+  void set(float _value);
   float get() const;
 
-  Gtk::SpinButton &get_spinbutton() const {return *spinbutton;}
-  Gtk::OptionMenu &get_optionmenu() const {return *optionmenu;}
+  Gtk::SpinButton &get_spinbutton() const { return *spinbutton; }
+  Gtk::OptionMenu &get_optionmenu() const { return *optionmenu; }
 
-  SigC::Signal0<void> signal_changed;
+  Glib::SignalProxy0<void> signal_value_changed();
 
 protected:
   /** Direct focus to the proper part of the Spinner. */
