@@ -51,7 +51,7 @@ namespace{
   typedef std::set<FrameWindow*> Windows;
   Windows windows; // a list of all windows
 
-  typedef std::vector<Glib::ustring> ZoomFactors;
+  typedef std::set<unsigned int> ZoomFactors;
   ZoomFactors zoom_factors;
 }
 
@@ -73,7 +73,8 @@ float str2float(const std::string& value) {
 FrameWindow *FrameWindow::active_window(0);
 
 FrameWindow::FrameWindow(const FrameWindow &original)
-  : document_view(original.document_view.get_document_meta()), 
+  : document_view(original.document_view.get_document_meta(),
+                  config.ZoomLevel.values.front() / 100.0), 
     open_dialog(new Filesel(*this, "Open")),
     save_dialog(new Filesel(*this, "Save As", true)), // accept non-existing
     print_dialog(new PrintDialog(*this, document_view)),
@@ -89,7 +90,8 @@ FrameWindow::FrameWindow(const Glib::ustring &filename, DocRef document)
   : document_view(DocMeta(filename.empty() 
 			  ? document
 			  : Document::create(filename, false),
-			  filename)),
+			  filename),
+                  config.ZoomLevel.values.front() / 100.0),
     open_dialog(new Filesel(*this, "Open")),
     save_dialog(new Filesel(*this, "Save As", true)), // accept non-existing
     print_dialog(new PrintDialog(*this, document_view)),
@@ -123,14 +125,16 @@ void FrameWindow::constructor_common() {
   zoom_lock = false;
   set_default_size(500, 700);
 
-  ErrorDialog::init(*this);
-
+  
   if(zoom_factors.empty()) {
-    zoom_factors.push_back("50 %");
-    zoom_factors.push_back("75 %");
-    zoom_factors.push_back("100 %");
-    zoom_factors.push_back("150 %");
-    zoom_factors.push_back("200 %");
+    unsigned int factors[] = {50, 75, 100, 150, 200, 0};
+    for(unsigned int *i = factors; *i; i++)
+      zoom_factors.insert(*i);
+    const Config::Floats &u_factors = config.ZoomLevel.values;
+    Config::Floats::const_iterator i;
+    for(i = u_factors.begin(); i != u_factors.end(); i++)
+      zoom_factors.insert(int(*i));
+    //    std::sort(zoom_factors.begin(), zoom_factors.end());
   }
 
   Gtk::VBox *mainbox = manage(new Gtk::VBox());
@@ -299,7 +303,7 @@ void FrameWindow::on_grid_button_clicked() {
 }
 
 void FrameWindow::do_nothing() const {
-  ErrorDialog::view("Not implemented yet.\nSorry.");
+  ErrorDialog::instance().show_error("Not implemented yet", "Sorry.");
 }
 
 void FrameWindow::set_filename(const Glib::ustring &filename) {
@@ -311,22 +315,21 @@ void FrameWindow::set_filename(const Glib::ustring &filename) {
 
 void FrameWindow::zoom_change_action(float factor) {
   if(!zoom_lock) {
-    Gtk::Menu_Helpers::MenuList::iterator i;
+    using namespace Gtk::Menu_Helpers;
+    MenuList::iterator i;
+    const MenuList &items = zoom_factor->get_menu()->items();
     int j;
-    for(i = zoom_factor->get_menu()->items().begin(), j=0;
-	i != zoom_factor->get_menu()->items().end();
-	i++, j++)
-      {
-	if(str2float(dynamic_cast<Gtk::Label&>
-		     (*(i->get_child())).get_text()) == factor) {
-	  zoom_factor->get_menu()->set_active(j);
-	  return;
-	} else if(str2float(dynamic_cast<Gtk::Label&>
-			    (*(i->get_child())).get_text())<factor) {
-	  warning << "Zoom factor " << factor 
-		  << " is not defined" << std::endl;
-	}
+    for(i = items.begin(), j = 0; i != items.end(); i++, j++) {
+      if(str2float(dynamic_cast<Gtk::Label&>
+                   (*(i->get_child())).get_text()) == factor) {
+        zoom_factor->get_menu()->set_active(j);
+        return;
+      } else if(str2float(dynamic_cast<Gtk::Label&>
+                          (*(i->get_child())).get_text()) < factor) {
+        warning << "Zoom factor " << factor 
+                << " is not defined" << std::endl;
       }
+    }
   }
 }
 
@@ -353,8 +356,12 @@ Gtk::Menu* FrameWindow::create_zoom_menu() {
   Menu *menu = manage(new Menu());
   MenuList& menu_list = menu->items();
   for(ZoomFactors::const_iterator i = zoom_factors.begin();
-      i != zoom_factors.end();  ++i)
-    menu_list.push_back(MenuElem(*i));
+      i != zoom_factors.end();  ++i) {
+    menu_list.push_back(MenuElem(tostr(*i) + " %"));
+    // the first value in ZoomLevel is the default
+    if(int(*i) == int(config.ZoomLevel.values.front()))
+      menu->set_active(menu->items().size() - 1);
+  }
 
   return menu;
 }
@@ -549,7 +556,9 @@ void FrameWindow::print_to_viewer() const {
 	document->print(out, 
 			document->get_first_page_num(), 
 			document->get_first_page_num() 
-			+ document->get_num_of_pages() - 1);
+			+ document->get_num_of_pages() - 1,
+                        false /* not eps */,
+                        true /* include fonts */);
 	verbose << psviewer + " " + preview_tmp_file << std::endl;
 	try {
 	  Glib::spawn_command_line_async(psviewer + " " + preview_tmp_file);
