@@ -1,19 +1,17 @@
 #ifndef WINDOW_H		// -*- c++ -*-
 #define WINDOW_H
 ///
-// Copyright (C) 2002, 2003, Fredrik Arnerup & Rasmus Kaj, See COPYING
+// Copyright (C) 2002 - 2004, Fredrik Arnerup & Rasmus Kaj, See COPYING
 ///
 #include "docview.h"
 #include <gtkmm/window.h>
+#include <memory> // auto_ptr
 
 class Icons;
 class Pagesel;
 class Filesel;
-class Print_Dialog;
-class Stream_Dialog;
-class PropertiesDialog;
-class Doc_Props_Dialog;
-class Undo_Dialog;
+class PrintDialog;
+class TextFrameDialog;
 
 namespace Gtk {
   class Button;  class ToggleButton;
@@ -27,35 +25,31 @@ namespace Gtk {
 /**
  * The main window containing a view of a Document.
  */
-class Frame_Window : public Gtk::Window 
-{
+class FrameWindow : public Gtk::Window {
 public:
-  Frame_Window(const Glib::ustring &filename = "", Document *document = 0);
-  ~Frame_Window();
+  FrameWindow(const Glib::ustring &filename = "", 
+	      DocRef document = Document::null());
 
-protected:
-  bool on_delete_event(GdkEventAny*);
-  bool on_focus_in_event(GdkEventFocus*);
-  bool on_key_press_event(GdkEventKey*);
+  /** Duplicate view */
+  FrameWindow(const FrameWindow&);
+  ~FrameWindow();
 
 private:
-  static Frame_Window *active_window; // pointer to the currently active window
-  static PropertiesDialog *properties_dialog;
-  static Stream_Dialog *stream_dialog;
-  static Doc_Props_Dialog *doc_props_dialog;
-  static Undo_Dialog *undo_dialog;
+  static FrameWindow *active_window; // pointer to the currently active window
   Gtk::Toolbar *toolbar;
   Gtk::ScrolledWindow *scroller;
   Gtk::Statusbar *cafe_opera;
   Gtk::MenuBar *menubar;
   Gtk::OptionMenu *zoom_factor;
-  Filesel *open_dialog, *save_dialog, *import_dialog;
-  Document_View document_view;
-  Print_Dialog *print_dialog;
+  DocumentView document_view;
+  std::auto_ptr<Filesel> open_dialog, save_dialog, import_dialog;
+  std::auto_ptr<PrintDialog> print_dialog;
+  std::auto_ptr<TextFrameDialog> text_frame_dialog;
   Pagesel *pagesel;
   Glib::ustring preview_tmp_file; // temp file to write ps to when previewing
   Gtk::Menu *page_menu, *edit_menu, *view_menu;
-  Gtk::MenuItem *save_item, *save_as_item, *print_item, *preview_item, 
+  Gtk::MenuItem *new_view_item, *save_item, *save_as_item, 
+    *print_item, *preview_item, 
     *delete_page_item, *undo_item, *redo_item, *props_item, *prefs_item;
   Gtk::Button *save_button, *text_frame_button, *image_frame_button;
   Gtk::Button *streams_button, *preview_button, *properties_button;
@@ -63,15 +57,21 @@ private:
 
   // We need to create separate copies of the icons for each window since each
   // icon can only have one parent
-  Icons *icons; 
+  std::auto_ptr<Icons> icons; 
 
+  bool on_delete_event(GdkEventAny*);
+  bool on_focus_in_event(GdkEventFocus*);
+  bool on_key_press_event(GdkEventKey*);
+
+  void constructor_common();
   void set_filename(const Glib::ustring&);
 
-  void on_document_updated(Document *document_); // change IN document
+  void on_document_updated(DocRef document_); // change IN document
   void on_document_changed(); // change OF document
-  void on_document_filename_changed(Document *document_); 
+  void on_document_filename_changed(); 
 
   void new_document();
+  void duplicate_view();
   void print_to_viewer() const;
   static void quit();
 
