@@ -5,8 +5,10 @@
 #include <stdexcept>
 #include <iomanip> 
 #include "encode.h"
+#include "util/warning.h"
 
-void PS::pfb2pfa(std::istream &in, std::ostream &out) {
+void PS::pfb2pfa(std::istream &in, std::ostream &out, 
+		 std::vector<long> *lengths) {
   in.exceptions(std::ios_base::eofbit); // throw exception on eof
   try {
     while(in) { // parse header
@@ -22,6 +24,10 @@ void PS::pfb2pfa(std::istream &in, std::ostream &out) {
       long length = 0;
       for(int i = 0; i < 4; i++) 
 	length |= in.get() << (i << 3);
+      
+      long blockstart = out.tellp();
+      if(blockstart == -1) blockstart = 0;
+      
       if(type == 1) { // ascii
 	unsigned char c;
 	for(long i = 0; i < length; i++) {
@@ -42,6 +48,9 @@ void PS::pfb2pfa(std::istream &in, std::ostream &out) {
 	}
 	filter.end();
       }
+      if(lengths) lengths->push_back(out.tellp() - blockstart);
+      debug << "Blockstart: " << blockstart << ", end: " << out.tellp()
+	    << "\n";
     }
   } catch (std::ios_base::failure) {
     throw std::runtime_error("unexpected end of file");
