@@ -53,6 +53,51 @@ ProcessRecord::ProcessRecord(const std::string& line)
   outbuf.reset(new filedesc::InBuf(ofiledes[0], true));
 }
 
+ProcessRecord::ProcessRecord(const std::vector<std::string>& args) {
+  int ofiledes[2], ifiledes[2];
+  // output from the external process (input to us)
+  if(pipe(ofiledes) == -1)
+    throw ClibException("Failed to create output pipe");
+  
+  // input to the external process (output from us)
+  if(pipe(ifiledes) == -1)
+    throw ClibException("Failed to create input pipe");
+  
+  pid = fork();
+  if(pid == -1)
+    throw ClibException("Failed to fork");
+  
+  if(pid == 0) {
+    // Convert the argument list so the c interface can use it.
+    const char** argv = new const char*[args.size()+1];
+    for(int i = 0; i < args.size(); ++i) {
+      argv[i] = args[i].c_str();
+    }
+    argv[args.size()] = 0;
+    
+    // Set up stdio
+    assert(filedesc::move(STDIN_FILENO, ifiledes[0]) == 0);
+    assert(filedesc::move(STDOUT_FILENO, ofiledes[1]) == 0);
+    close(ifiledes[1]); close(ofiledes[0]);
+    /// \todo  Close all file descriptors above 2!
+    
+    execvp(const_cast<char*>(argv[0]), const_cast<char**>(argv));
+    delete[] argv;
+    exit(127);
+  }
+  close(ifiledes[0]); close(ofiledes[1]);
+  inbuf.reset(new filedesc::OutBuf(ifiledes[1], true));
+  outbuf.reset(new filedesc::InBuf(ofiledes[0], true));
+}
+
+int ProcessRecord::wait() {
+  int status;
+  if(waitpid(get_pid(), &status, 0) == -1 || !WIFEXITED(status))
+    return -1; // no process or abnormal termination
+  else
+    return WEXITSTATUS(status); // return exit status
+}
+
 std::ostream& ProcessRecord::get_cin() {
   if(!inbuf.get())
     throw std::runtime_error("Tried to get closed process stream");
@@ -98,8 +143,17 @@ Process ProcessManager::run(const std::string& command) {
   return result;
 }
 
-pid_t ProcessManager::start(std::string command) {
-  return run(command)->get_pid();
+Process ProcessManager::run(const std::vector<std::string>& command) {
+  Process result(new ProcessRecord(command));
+  result->reference();
+  processes[result->get_pid()] = result;
+  return result;
+}
+
+int ProcessManager::system(std::vector<std::string>& command) {
+  Process proc(new ProcessRecord(command));
+  proc->reference();
+  return proc->wait();
 }
 
 int ProcessManager::system(std::string command) {
