@@ -1,5 +1,5 @@
 ///
-// Copyright (C) 2002, 2003, Fredrik Arnerup & Rasmus Kaj, See COPYING
+// Copyright (C) 2002 - 2004, Fredrik Arnerup & Rasmus Kaj, See COPYING
 ///
 #include "rectboundary.h"
 #include <iostream>
@@ -63,6 +63,17 @@ bool RectBoundary::isInsideOrClose(const Vector& v, const float& dist) {
   return ((i.x >= -d2 && i.x <= 1+d2 && i.y >= -d2 && i.y <= 1+d2));
 }
 
+void RectBoundary::grow(const float& amount) {
+  Matrix m2(matrix);
+  m2.set_scale(1,1);
+  Vector size(matrix.sc_x(), matrix.sc_y());
+  size += Vector(2*amount, 2*amount);
+  Vector origo = m2.transform(Vector(-amount, -amount));
+  m2.set_tr(origo);
+  m2.set_scale(size.x, size.y);
+  matrix = m2;
+}
+
 bool RectBoundary::equals(const BoundaryBase* other) const {
   const RectBoundary* other_r = dynamic_cast<const RectBoundary*>(other);
   return other_r && matrix == other_r->matrix;
@@ -84,3 +95,6 @@ Polygon RectBoundary::get_polygon() {
   result.push_back(getCorner(Corner::LR));
   return result;
 }
+
+float RectBoundary::get_width()  const { return matrix.sc_x(); }
+float RectBoundary::get_height() const { return matrix.sc_y(); }
