@@ -1,7 +1,7 @@
 #ifndef STRINGUTIL_H		// -*- c++ -*-
 #define STRINGUTIL_H
 ///
-// Copyright (C) 2002, 2003, Fredrik Arnerup & Rasmus Kaj, See COPYING
+// Copyright (C) 2002 - 2004, Fredrik Arnerup & Rasmus Kaj, See COPYING
 ///
 #include "typeinfo.h"
 #include <string>
@@ -22,7 +22,7 @@ C to(const std::string &value) {
   std::istringstream s(value);
   C c;
   if(s >> c) {
-    if(!s.eof())
+    if(!s.eof() && s.peek() != EOF)
       throw std::runtime_error("Trailing junk in " + TypeInfo<C>::name()
 			       + " \"" + value + '"');
     return c;
@@ -31,6 +31,12 @@ C to(const std::string &value) {
 			     + value + '"');
 }
 
+/** Specialization; a string is "converted" to itself without change. */
+template<> 
+inline std::string to<std::string>(const std::string& value) {
+  return value;
+}
+
 /**
  * Convert a value of an arbitrary type to its string representation.
  * \param C the type of value (can be implicit).
