@@ -75,10 +75,17 @@ void xml2ps::PsConverter::on_end_element(const std::string &n) {
 	
       } catch(const std::exception& err) {
 	throw(ParserError("close <" + n + "> - " + err.what()));
+
+      } catch(const Glib::Error& err) { // Glib::Error is not a
+					// std::exception :-(
+	throw(ParserError("close <" + n + "> - " + err.what()));
       }
       if(!element_stack.empty())
 	element_stack.pop_back();
     }
+void xml2ps::PsConverter::on_cdata_block(const std::string& s) {
+  on_characters(s);
+}
 void xml2ps::PsConverter::on_characters(const std::string& s) {
       try {
 	using xml2ps::TextContainer;
@@ -133,37 +140,41 @@ namespace xml2ps {
   }
 
   void Typesetter::run(std::istream &input, std::ostream &output) {
-    xml2ps::Canvas *out;
+    PDF::Document::Ptr pdfdoc;
+    std::auto_ptr<xml2ps::Canvas> out;
+    
     switch(output_format) {
     case FORMAT_PS:
-      out = new xml2ps::PsCanvas(pages, extra_pages);
+      out.reset(new xml2ps::PsCanvas(pages, extra_pages));
       break;
     case FORMAT_PDF:
-      out = new xml2ps::PDFCanvas(output.rdbuf(), 
-				  pages, extra_pages);
+      pdfdoc = PDF::Document::create();
+      out.reset(new xml2ps::PDFCanvas(pdfdoc, PDFCanvas::Pages, 
+				      pages, extra_pages));
       break;
     case FORMAT_X:
-      out = new xml2ps::XCanvas(pages, extra_pages);
+      out.reset(new xml2ps::XCanvas(pages, extra_pages));
       break;
     default:
       throw std::runtime_error("Uncaught output format");
       break;
     }
-    try {
+
       out->setSubstituteFontAliases(subst_font_aliases);
       PsConverter parser(*out);
       parser.parse_stream(input);
+      out->closePage();
       used_fonts = out->getUsedFonts();
-      if(output_format == FORMAT_PS) {
-	// must flush before merge /// \todo fix this
-	dynamic_cast<PsCanvas*>(out)->flush();
-	dynamic_cast<PsCanvas*>(out)->merge(output);
+      switch(output_format) {
+      case FORMAT_PS:
+	dynamic_cast<PsCanvas*>(out.operator->())->merge(output);
+	break;
+	
+      case FORMAT_PDF:
+	pdfdoc->write(output);
+	break;
+	
+      default: break;
       }
-      
-      delete out;
-    } catch (...) {
-      delete out;
-      throw;
-    }
   }
 };
